#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Créé le Wed Jun 22 13:30:04 2022

@auteur: David ALBERTO
(www.astrolabe-science.fr)

source des données :
https://www.nrel.gov/grid/solar-resource/spectra.html
"""
import matplotlib.pyplot as plt
import numpy as np
import pandas as pd

plt.rcParams["font.family"] = "Roboto"# ou autre police installée.

donnees = pd.read_csv("astmg173.csv",sep='\t',
                      skiprows=2,
                      usecols=[0,1,2],
                      names=['lam','flux_ET','flux_sol'])

lam=donnees['lam']# longueur d'onde (nanomètres)
flux_ET=donnees['flux_ET']
flux_sol=donnees['flux_sol']

fig = plt.figure(figsize=(29.7/2.54,21/2.54))# format A4 paysage

ax = plt.subplot(111)

ax.set_title('Rayonnement solaire sur Terre',fontsize=16)
ax.set_xlabel("longueur d'onde (nm)")
ax.set_ylabel(r"Irradiance ($W\cdot m^{-2} \cdot nm^{-1}$)")
ax.set_xticks(np.arange(200,2600,200))
ax.set_xlim(250,2600)
ax.set_ylim(0,2.25)

ax.plot(lam,flux_ET, c='indigo', lw=1,label="hors atmosphère")
ax.plot(lam,flux_sol, c='firebrick', lw=1,label="au sol")

plt.fill_between(lam, 0, flux_sol, color='goldenrod')

leg=ax.legend()
for line in leg.get_lines():# épaissir les lignes des légendes
    line.set_linewidth(4.0)
    

# légendes manuelles
ax.text(260,0.04, r"$\mathbf{O_3}$")
ax.text(750,0.1,r"$\mathbf{O_2}$",)

for coord in [[920,0.05],[1120,0.6],[1350,0.25],[1850,0.05],[2500,0.07]]:
    ax.text(coord[0],coord[1], r"$\mathbf{H_2O}$")
    
ax.text(2000,0.15, r"$\mathbf{CO_2}$")

# limites du visible :
ax.axvline(400, ls='--', color='gray', linewidth='0.5',zorder=0)
ax.axvline(800, ls='--', color='gray', linewidth='0.5',zorder=0)
props = dict(boxstyle='round', facecolor='white', linewidth=0, pad=0.3)
ax.annotate("", xy=(400, 2.2), xytext=(800, 2.2),
             arrowprops=dict(arrowstyle="<|-|>"))
ax.text(600, 2.2, "domaine visible", fontsize=8, bbox=props,
        ha='center', va='center')


ax.text(1.01,0.0,"D. Alberto (www.astrolabe-science.fr)   "
        "Données : https://www.nrel.gov/grid/solar-resource/spectra.html"
        ,rotation=90,
        transform=ax.transAxes,fontsize=8)

fig.savefig("rayonnement_solaire_sol.png",dpi=300)
fig.savefig("rayonnement_solaire_sol.pdf")
